summaryrefslogtreecommitdiff
path: root/lib/int.h
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2012-10-01 21:55:54 +0200
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2012-10-01 22:14:09 +0200
commit97f40453042a02371269f2d7af6f46928276ece8 (patch)
tree360a07c62a93f60605ec8cf1e27aff5c237a1134 /lib/int.h
parent901a49ced275c448e21177b64f6fe85f1d4208b2 (diff)
downloadlibtasn1-97f40453042a02371269f2d7af6f46928276ece8.tar.gz
libtasn1-97f40453042a02371269f2d7af6f46928276ece8.tar.bz2
libtasn1-97f40453042a02371269f2d7af6f46928276ece8.zip
Renamed types.
node_asn -> asn_node_st ASN1_TYPE -> node_asn_t ASN1_TYPE_EMPTY -> NULL
Diffstat (limited to 'lib/int.h')
-rw-r--r--lib/int.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/int.h b/lib/int.h
index 9e6bc89..6643ffb 100644
--- a/lib/int.h
+++ b/lib/int.h
@@ -43,7 +43,7 @@
/* This structure is also in libtasn1.h, but then contains less
fields. You cannot make any modifications to these first fields
without breaking ABI. */
-struct node_asn_struct
+struct asn_node_st
{
/* public fields: */
char name[ASN1_MAX_NAME_SIZE+1]; /* Node name */
@@ -51,9 +51,9 @@ struct node_asn_struct
unsigned int type; /* Node type */
unsigned char *value; /* Node value */
int value_len;
- ASN1_TYPE down; /* Pointer to the son node */
- ASN1_TYPE right; /* Pointer to the brother node */
- ASN1_TYPE left; /* Pointer to the next list element */
+ asn_node_t down; /* Pointer to the son node */
+ asn_node_t right; /* Pointer to the brother node */
+ asn_node_t left; /* Pointer to the next list element */
/* private fields: */
unsigned char small_value[ASN1_SMALL_VALUE_SIZE]; /* For small values */
};
@@ -75,11 +75,11 @@ uint32_t _asn1_bhash( const void *key, size_t length);
/****************************************/
/* Returns the first 8 bits. */
/* Used with the field type of node_asn */
/****************************************/
#define type_field(x) (x&0xFF)
/* List of constants for field type of typedef node_asn */
#define TYPE_CONSTANT ASN1_ETYPE_CONSTANT
#define TYPE_IDENTIFIER ASN1_ETYPE_IDENTIFIER
#define TYPE_INTEGER ASN1_ETYPE_INTEGER
@@ -105,7 +105,7 @@ uint32_t _asn1_bhash( const void *key, size_t length);
/***********************************************************************/
/* List of constants to better specify the type of typedef node_asn. */
/***********************************************************************/
/* Used with TYPE_TAG */
#define CONST_UNIVERSAL (1<<8)
@@ -75,11 +75,11 @@ uint32_t _asn1_bhash( const void *key, size_t length);
/****************************************/
/* Returns the first 8 bits. */
-/* Used with the field type of node_asn */
+/* Used with the field type of asn_node_st */
/****************************************/
#define type_field(x) (x&0xFF)
@@ -75,11 +75,11 @@ uint32_t _asn1_bhash( const void *key, size_t length);
/****************************************/
#define type_field(x) (x&0xFF)
-/* List of constants for field type of typedef node_asn */
+/* List of constants for field type of typedef asn_node_st */
#define TYPE_CONSTANT ASN1_ETYPE_CONSTANT
#define TYPE_IDENTIFIER ASN1_ETYPE_IDENTIFIER
@@ -105,7 +105,7 @@ uint32_t _asn1_bhash( const void *key, size_t length);
/***********************************************************************/
-/* List of constants to better specify the type of typedef node_asn. */
+/* List of constants to better specify the type of typedef asn_node_st. */
/***********************************************************************/
/* Used with TYPE_TAG */